#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-date
version:              0.0.11
visibility:           public
id:                   http-date-0.0.11-33hBVTm4QXYIvO8E8IofwR
key:                  http-date-0.0.11-33hBVTm4QXYIvO8E8IofwR
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             HTTP Date parser/formatter
description:          Fast parser and formatter for HTTP Date
category:             Network, Web
abi:                  6f3c16b15cdbb7b309e107c1fc714826
exposed:              True
exposed-modules:      Network.HTTP.Date
hidden-modules:
    Network.HTTP.Date.Converter Network.HTTP.Date.Formatter
    Network.HTTP.Date.Types Network.HTTP.Date.Parser

import-dirs:          /usr/lib/ghc-9.6.6/site-local/http-date-0.0.11
library-dirs:         /usr/lib/ghc-9.6.6/site-local/http-date-0.0.11
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/http-date-0.0.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-date
hs-libraries:         HShttp-date-0.0.11-33hBVTm4QXYIvO8E8IofwR
depends:
    array-0.5.6.0 attoparsec-0.14.4-9B3gn5pX08KJB1CStsvQz6
    base-4.18.2.1 bytestring-0.11.5.3 time-1.12.2

haddock-interfaces:   /usr/share/doc/haskell-http-date/html/http-date.haddock
haddock-html:         /usr/share/doc/haskell-http-date/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

